# Examples 
In this folder are some examples for using the wrapper.

Please submit your own examples, I would very much appreciate it. To submit one just create a pull request
or contact me on Discord.
